@@ -4,6 +4,7 @@ import sys
 import PyQt5
 from PyQt5.QtCore import QThread,pyqtSignal
 from PyQt5 import QtCore, QtGui, uic, QtWidgets
+from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QApplication, QMainWindow, QFileDialog, QMessageBox, QFileSystemModel, QTableWidgetItem
 from quick_topic.gui.main import Ui_MainWindow
 from quick_topic.gui_functions.gui_topic_interaction import *
@@ -15,8 +16,13 @@ from quick_topic.gui_functions.gui_topic_transition_topic_year import *
 from quick_topic.gui_functions.gui_topic_trends import *
 from quick_topic.gui_functions.gui_topic_trends_correlation import *
 from quick_topic.gui_functions.gui_topic_transition_term_year import *
+from quick_topic.gui_functions.gui_topic_explore import *
 import pyqtgraph as pg
 
+import ctypes
+myappid = 'quick-topic-tool-gui' # arbitrary string
+ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
+
 if hasattr(QtCore.Qt, 'AA_EnableHighDpiScaling'):
     PyQt5.QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
 
@@ -28,6 +34,11 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
     def __init__(self, parent=None):
         super(MyMainForm, self).__init__(parent)
         self.setupUi(self)
+
+        current_path = os.path.realpath(__file__)
+        app_icon = QIcon( "qtt.png")
+        self.setWindowIcon(app_icon)
+
         self.btnOpen.clicked.connect(self.select_file)
         self.btnBrowse.clicked.connect(self.select_folder)
         self.btnBrowseOutput.clicked.connect(self.select_output_folder)
@@ -44,6 +55,9 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         self.btnPlot.clicked.connect(self.plot)
         self.btn_clear_plot.clicked.connect(self.clear_plot)
         self.btn_bar.clicked.connect(self.plot_bar)
+        self.btn_explore.clicked.connect(self.explore_topic)
+        self.btn_select_chinese_font.clicked.connect(self.open_chinese_font_file)
+
         # self.table_show.selectedIndexes.connect(self.selected)
         # plot chart
         self.graphWidget = pg.PlotWidget()
@@ -174,6 +188,12 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
                 plot=self.graphWidget.plot(list_value[0], list_value[1], label=self.cols[list_cols[1]],pen=pen, symbol='+')
                 self.list_plot.append(plot)
 
+    def open_chinese_font_file(self):
+        path = QFileDialog.getOpenFileName(self, 'Load a chinese font file', '',
+                                           'All Files (*.*)')
+        if path != ('', ''):
+            print("Load chinese file path : " + path[0])
+            self.edit_chinese_font.setText(path[0])
 
     def save_config_file_event(self):
         path = QFileDialog.getSaveFileName(self, 'Save a config file', '',
@@ -242,6 +262,43 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             print("File path : " + path[0])
             self.edit_keywords_file.setText(path[0])
 
+    def explore_topic(self):
+        self.save_config()
+        meta_csv_file = self.edit_metafile.text()
+        print(meta_csv_file)
+        raw_text_folder = self.edit_raw_folder.text()
+        output_folder = self.edit_output_path.text()
+        topic_file = self.edit_predefined_topic.text()
+        category_field = self.field_category.text()
+        id_field = self.field_id.text()
+        time_field = self.field_time.text()
+        lang = self.field_lang.text()
+        num_topics = self.numTopics.value()
+        num_words = self.numWords.value()
+        stopwords_path = self.edit_stopwords_file.text()
+        result_path = self.edit_result_path.text()
+        prefix_filename = self.edit_prefix.text()
+
+        target_folder = f"{output_folder}/topic_explore"
+        if not os.path.exists(target_folder):
+            os.mkdir(target_folder)
+
+        gui_topic_explore(
+            meta_csv_file=meta_csv_file,
+            raw_text_folder=raw_text_folder,
+            output_folder=target_folder,
+            stopwords_path=stopwords_path,
+            lang=lang,
+            num_topics=num_topics,
+            num_words=num_words,
+            prefix_filename=prefix_filename,
+            n_rows=int(self.edit_rows.text()),
+            n_cols=int(self.edit_cols.text()),
+            max_records=int(self.edit_max_records.text()),
+            chinese_font_file=self.edit_chinese_font.text()
+        )
+
+        QMessageBox.about(self, "Tips", "Finished!")
 
 
     def run_topic_interaction(self):
@@ -261,6 +318,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         num_words = self.numWords.value()
         stopwords_path=self.edit_stopwords_file.text()
         result_path=self.edit_result_path.text()
+        prefix_filename=self.edit_prefix.text()
 
         target_folder=f"{output_folder}/topic_interaction"
         if not os.path.exists(target_folder):
@@ -278,7 +336,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             num_topics=num_topics,
             num_words=num_words,
             stopwords_path=stopwords_path,
-            result_path=result_path
+            result_path=result_path,
+            prefix_filename=prefix_filename
         )
         # QMessageBox.about(self, "Tips", "Finished!")
 
@@ -297,7 +356,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         num_words = self.numWords.value()
         stopwords_path = self.edit_stopwords_file.text()
         result_path=self.edit_result_path.text()
-
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/topic_prevalence"
         if not os.path.exists(target_folder):
@@ -319,7 +378,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             num_topics=num_topics,
             num_words=num_words,
             stopwords_path=stopwords_path,
-            result_path=result_path
+            result_path=result_path,
+            prefix_filename=prefix_filename
         )
 
     def run_keyword_stat(self):
@@ -332,6 +392,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         output_folder = self.edit_output_path.text()
         topic_file = self.edit_predefined_topic.text()
         id_field = self.field_id.text()
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/keyword_stat"
         if not os.path.exists(target_folder):
@@ -342,7 +403,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             raw_text_folder=raw_text_folder,
             predefined_topic_file=topic_file,
             id_field=id_field,
-            result_path=result_path
+            result_path=result_path,
+            prefix_filename=prefix_filename
         )
 
         # write_csv(f"{result_path}/ks_keywords.csv",list_item)
@@ -365,6 +427,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         num_topics = self.numTopics.value()
         num_words = self.numWords.value()
         stopwords_path = self.edit_stopwords_file.text()
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/topic_modeling"
         if not os.path.exists(target_folder):
@@ -379,7 +442,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             num_topics=num_topics,
             num_words=num_words,
             stopwords_path=stopwords_path,
-            lang=lang
+            lang=lang,
+            prefix_filename=prefix_filename
         )
 
     def run_topic_transition_year(self):
@@ -399,6 +463,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         end_year = self.numEndYear.value()
         result_path=self.edit_result_path.text()
         show_figure = self.cbDisplayFigure.isChecked()
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/topic_transition"
         if not os.path.exists(target_folder):
@@ -416,7 +481,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             id_field=id_field,
             lang=lang,
             result_path=result_path,
-            show_figure=show_figure
+            show_figure=show_figure,
+            prefix_filename=prefix_filename
         )
 
     def run_term_transition_year(self):
@@ -437,6 +503,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         select_keywords_file=self.edit_keywords_file.text()
         result_path = self.edit_result_path.text()
         show_figure=self.cbDisplayFigure.isChecked()
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/term_transition"
         if not os.path.exists(target_folder):
@@ -453,7 +520,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             id_field=id_field,
             tag_field=category_field,
             result_path=result_path,
-            show_figure=show_figure
+            show_figure=show_figure,
+            prefix_filename=prefix_filename
         )
 
     def run_topic_trends(self):
@@ -469,6 +537,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         start_year = self.numStartYear.value()
         end_year = self.numEndYear.value()
         result_path = self.edit_result_path.text()
+        prefix_filename = self.edit_prefix.text()
 
         target_folder = f"{output_folder}/topic_trends"
         if not os.path.exists(target_folder):
@@ -484,6 +553,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             minimum_year=start_year,
             time_field=time_field,
             id_field=id_field,
+            prefix_filename=prefix_filename
         )
 
     def run_topic_trends_correlation(self):
@@ -494,6 +564,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         label_names=self.edit_labelnames.text()
         result_path = self.edit_result_path.text()
         QtCore.QCoreApplication.processEvents()
+        prefix_filename = self.edit_prefix.text()
 
         gui_tropic_trends_correlation(
             trends_file=trends_file,
@@ -501,7 +572,8 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             time_field=time_field,
             start_year=start_year,
             end_year=end_year,
-            result_path=result_path
+            result_path=result_path,
+            prefix_filename=prefix_filename
         )
 
     def run_topic_similarity(self):
@@ -519,6 +591,7 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
         num_words=self.numWords.value()
         result_path = self.edit_result_path.text()
         target_folder = f"{output_folder}/topic_similarity"
+        prefix_filename = self.edit_prefix.text()
         if not os.path.exists(target_folder):
             os.mkdir(target_folder)
 
@@ -534,8 +607,10 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             lang=lang,
             num_topics=num_topics,
             num_words=num_words,
-            result_path=result_path
+            result_path=result_path,
+            prefix_filename=prefix_filename
         )
+
     def save_config_file(self,filename):
         config_model = {
             "meta_csv_file": self.edit_metafile.text(),
@@ -555,7 +630,12 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
             "stopwords_file": self.edit_stopwords_file.text(),
             "keywords_file": self.edit_keywords_file.text(),
             "result_path": self.edit_result_path.text(),
-            "show_figure": self.cbDisplayFigure.isChecked()
+            "show_figure": self.cbDisplayFigure.isChecked(),
+            "prefix_filename":self.edit_prefix.text(),
+            "n_rows":self.edit_rows.text(),
+            "n_cols":self.edit_cols.text(),
+            "max_records":self.edit_max_records.text(),
+            "chinese_font_file":self.edit_chinese_font.text()
         }
         pickle.dump(config_model, open(filename, "wb"))
 
@@ -590,6 +670,16 @@ class MyMainForm(QMainWindow, Ui_MainWindow):
                 self.edit_result_path.setText(config_model['result_path'])
             if 'show_figure' in config_model:
                 self.cbDisplayFigure.setChecked(config_model['show_figure'])
+            if 'prefix_filename' in config_model:
+                self.edit_prefix.setText(config_model['prefix_filename'])
+            if 'n_rows' in config_model:
+                self.edit_rows.setText(config_model['n_rows'])
+            if 'n_cols' in config_model:
+                self.edit_cols.setText(config_model['n_cols'])
+            if 'max_records' in config_model:
+                self.edit_max_records.setText(config_model['max_records'])
+            if 'chinese_font_file' in config_model:
+                self.edit_chinese_font.setText(config_model['chinese_font_file'])
         else:
             print("Config file not exists")
 
@@ -764,6 +854,11 @@ class WorkThread(QThread):
 
 def main():
     app = QApplication(sys.argv)
+
+    current_path = os.path.realpath(__file__)
+    app_icon = QIcon("qtt.png")
+    app.setWindowIcon(app_icon)
+
     myWin = MyMainForm()
     myWin.show()
     sys.exit(app.exec_())
