@@ -25,7 +25,8 @@ def gui_topic_transition_topic_year(
         id_field='file_id',
         lang="en",
         result_path="",
-        show_figure=True
+        show_figure=True,
+        prefix_filename=""
            ):
     output_divided_folder = f"{output_folder}/divided_year"
     if not os.path.exists(output_divided_folder):
@@ -44,7 +45,7 @@ def gui_topic_transition_topic_year(
         id_field=id_field,
         tag_field=category_field,
         time_field=time_field,
-        prefix_filename=''
+        prefix_filename=prefix_filename
     )
 
     label_names, list_topics = get_predefined_topics(predefined_topic_file=predefined_topic_file)
