@@ -22,7 +22,8 @@ def gui_topic_trends(
         predefined_topic_file="",
         minimum_year=2010,
         id_field='file_id',
-        time_field='PY'
+        time_field='PY',
+        prefix_filename=""
 ):
 
     label_names,list_topics=get_predefined_topics(predefined_topic_file)
@@ -37,5 +38,5 @@ def gui_topic_trends(
         raw_text_path=raw_text_folder,
         id_field=id_field,
         time_field=time_field,
-        prefix_filename=""
+        prefix_filename=prefix_filename
     )
