@@ -194,15 +194,17 @@ def lda_by_tag_each(list_category,root_path,weights_path,list_keywords_path,stop
         os.mkdir(weights_path)
     print("Building topic models...")
     for country in list_category:
+        if country.strip()=="":
+            continue
         list_doc = []
 
-        if not os.path.exists(os.path.join(root_path, country)):
+        if not os.path.exists(f"{root_path}/{country}"):
             continue
-        for file in os.listdir(os.path.join(root_path, country)):
-            folder = f"{root_path}/{country}/{file}"
-            if not os.path.exists(folder):
+        for file in os.listdir(f"{root_path}/{country}"):
+            text_file = f"{root_path}/{country}/{file}"
+            if not os.path.exists(text_file):
                 continue
-            text = open(folder, "r", encoding='utf-8').read()
+            text = open(text_file, "r", encoding='utf-8').read()
             list_doc.append(text)
         if len(list_doc) >= minimum_num_doc:
             print(country,len(list_doc))
