@@ -1,5 +1,6 @@
 from gensim import  models
 from quick_topic.topic_interaction.lda_by_tag_each import *
+from quickcsv.file import *
 
 def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file=None,stopwords_path="",save_name="topic",output_folder="output",lang='zh',
                     random_state=100,
@@ -63,7 +64,12 @@ def build_lda_model(list_doc,num_topics=6,num_words=50,num_pass=5,list_term_file
                                                    num_topics=NUM_TOPICS,
                                                    id2word=dictionary,
                                                    passes=NUM_PASS,
-
+                                                   random_state=random_state,
+                                                   update_every=1,
+                                                   chunksize=chunk_size,
+                                                   alpha='symmetric',
+                                                   iterations=iteration,
+                                                   per_word_topics=True
                                                    )
 
     ## list_topic_weights=get_topic_weights(ldamodel=ldamodel,corpus=corpus)
@@ -171,6 +177,8 @@ def build_lda_models(meta_csv_file,raw_text_folder,tag_field="area",id_field="fi
 
     for item in list_item:
         area = item[tag_field]
+        if area.strip()=="":
+            continue
         id = item[id_field]
         text_path = f'{raw_text_folder}/{prefix_filename}{id}.txt'
         if not os.path.exists(text_path):
