@@ -9,7 +9,10 @@ import matplotlib
 import numpy as np
 
 
-def create_keyword_distribution(root_path, keyword,save_figure=False,list_range=None,start_year=2000,end_year=2021,output_figure_folder="",min_total_num=10,maximum_rate_if_meet_min_num=0.8,font_size=16,style="seaborn-deep"):
+def create_keyword_distribution(root_path, keyword,save_figure=False,list_range=None,start_year=2000,end_year=2021,output_figure_folder="",
+                                min_total_num=10,maximum_rate_if_meet_min_num=0.8,font_size=16,style="seaborn-deep",
+y_label='Share of document',x_label='Year'
+                                ):
     matplotlib.rcParams.update({'font.size': font_size})
     plt.style.use(style)
 
@@ -21,8 +24,11 @@ def create_keyword_distribution(root_path, keyword,save_figure=False,list_range=
 
     for year in range(start_year, end_year+1):
         for month in range(1, 13):
-            year_month = f"{year}-{month}"
-            year_month_folder = f"{root_path}/{year}-{month}"
+            month_str=str(month)
+            if month<10:
+                month_str="0"+month_str
+            year_month = f"{year}-{month_str}"
+            year_month_folder = f"{root_path}/{year}-{month_str}"
             if not os.path.exists(year_month_folder):
                 continue
             total_num = 0
@@ -57,7 +63,7 @@ def create_keyword_distribution(root_path, keyword,save_figure=False,list_range=
         x.append(year_month)
         y.append(rate)
 
-    show_scatter(label_name, x, y,save_figure=save_figure,list_range=list_range,output_figure_folder=output_figure_folder)
+    show_scatter(label_name, x, y,save_figure=save_figure,list_range=list_range,output_figure_folder=output_figure_folder,x_label=x_label,y_label=y_label)
 
 def get_sub_plot(min,max,x,y):
     ys=[]
@@ -74,13 +80,13 @@ def get_sub_plot(min,max,x,y):
         ys[idx]=y_mean
     return xs,ys
 
-def show_scatter(title,x,y,save_figure=False,list_range=None,output_figure_folder=""):
+def show_scatter(title,x,y,save_figure=False,list_range=None,output_figure_folder="",y_label='Share of document',x_label='Year'):
 
     import numpy as np
     dates = [pd.to_datetime(d) for d in x]
     plt.title(title)
-    plt.ylabel("Share of document")
-    plt.xlabel("Year")
+    plt.ylabel(y_label)
+    plt.xlabel(x_label)
     # plt.xlim(left=2000,right=2021)
     # plt.ylim(bottom=0)
     plt.scatter(dates, y)
@@ -98,7 +104,9 @@ def show_scatter(title,x,y,save_figure=False,list_range=None,output_figure_folde
     # plt.show()
     plt.clf()
 
-def show_transition_by_year_month_term(root_path,select_keywords,start_year,end_year,list_all_range=None,output_figure_folder=""):
+def show_transition_by_year_month_term(root_path,select_keywords,start_year,end_year,list_all_range=None,output_figure_folder="",
+min_total_num=10,maximum_rate_if_meet_min_num=0.8,font_size=16,y_label='Share of document',x_label='Year'
+                                       ):
     if output_figure_folder!="":
         if not os.path.exists(output_figure_folder):
             os.mkdir(output_figure_folder)
@@ -107,4 +115,7 @@ def show_transition_by_year_month_term(root_path,select_keywords,start_year,end_
         rr=None
         if list_all_range!=None:
             rr = list_all_range[idx]
-        create_keyword_distribution(root_path=root_path, keyword=k, save_figure=True, list_range=rr,start_year=start_year,end_year=end_year,output_figure_folder=output_figure_folder)
+        create_keyword_distribution(root_path=root_path, keyword=k, save_figure=True, list_range=rr,start_year=start_year,end_year=end_year,output_figure_folder=output_figure_folder,
+                                    min_total_num=min_total_num, maximum_rate_if_meet_min_num=maximum_rate_if_meet_min_num, font_size=font_size,
+                                    x_label=x_label,y_label=y_label
+                                    )
