@@ -584,9 +584,9 @@ def show_tsne(lda_model,corpus,num_topics=4,output_folder=""):
  step 13: pyLDAvis
 '''
 def show_pyLDAvis(lda_model,corpus,output_folder="",save_file="pyLDAvis.html"):
-    import pyLDAvis.gensim
+    import pyLDAvis.gensim_models
     # pyLDAvis.enable_notebook()
-    vis = pyLDAvis.gensim.prepare(lda_model, corpus, dictionary=lda_model.id2word)
+    vis = pyLDAvis.gensim_models.prepare(lda_model, corpus, dictionary=lda_model.id2word)
     pyLDAvis.save_html(vis, output_folder+'/'+save_file)
 
 def run_topic_modeling_pipeline(
